import unittest
import sys
import numpy as np
import cupy as cp

sys.path.append('../')
from cycoda.clr import gmean, clr

class gmeanTests(unittest.TestCase):
    def testOutput_1(self):
        eo = np.array([4])
        o = clr(cp.array([2, 8])).get()

        self.assertEqual(o, eo)
    
    def testOutput_2(self):
        eo = np.array([0.5])
        o = clr(cp.array([4, 1, 1/32])).get()

        self.assertEqual(o, eo)
        self.assertTr

class clrTests(unittest.TestCase):
    def testOutput(self):
        eo = np.array([-0.59725316,  0.09589402,  0.50135913])
        o = clr(cp.array([1, 2, 3]))

        self.assertEqual(o, eo)

if __name__ == '__main__':
    unittest.main()


import numpy as np
import sys
from scipy.stats import gmean as scipy_gmean
from cycoda.gmean import gmean as cycoda_gmean

def composition_1d():
    return np.array([1, 2, 3])

def composition_2d():
    return np.array([[1, 2, 3], [4, 5, 6]])

def test_gmean_1d():
    matrix = composition_1d()
    expected = scipy_gmean(matrix)
    actual = cycoda_gmean(matrix)
    assert expected == actual, f"gmean in cycoda failed: expected {expected}, but got {actual}"

def test_gmean_2d():
    matrix = composition_2d()
    expected = scipy_gmean(matrix, axis=1)
    actual = cycoda_gmean(matrix, axis=1)
    assert (expected==actual).all(), f"gmean in cycoda failed: expected {expected}, but got {actual}"




import numpy as np
import sys
from scipy.stats import gmean
from cycoda.transformations import alr, clr, rclr

def composition_1d():
    return np.array([1, 2, 3])

def composition_2d():
    return np.array([[1, 2, 3], [4, 5, 6]])

def test_alr_1d(): 
    matrix = composition_1d()
    expected = np.log(np.array([[1/3, 2/3]]))
    actual = alr(matrix)
    assert np.all(expected == actual), f"ALR transformation failed: expected {expected}, but got {actual}"

def test_alr_2d():
    matrix = composition_2d()
    expected = np.log(np.array([[1/3, 2/3], [4/6, 5/6]]))
    actual = alr(matrix)
    assert np.all(expected == actual), f"ALR transformation failed: expected {expected}, but got {actual}"

def test_clr_1d():
    matrix = composition_1d()
    expected = np.array([-0.59725316, 0.09589402,  0.50135913])
    actual = clr(matrix)
    assert np.all(expected.round(3) == actual.round(3)), f"CLR transformation failed: expected {expected}, but got {actual}"

def test_clr_2d():
    matrix = composition_2d()
    expected = np.array([[-0.59725316, 0.09589402,  0.50135913], [-0.209536,    0.013607,    0.195929  ]])
    actual = clr(matrix)
    assert np.all(expected.round(3) == actual.round(3)), f"CLR transformation failed: expected {expected.reshape(-1)}, but got {actual.reshape(-1)}"



from setuptools import setup

setup()

# setup(
#    name='cycoda',
#    version='0.0.1',
#    author="Hannah-Marie Martiny",
#    packages=["cycoda"],
#    author_email="hanmar@food.dtu.dk",
#    install_requires=['numpy', 'pandas', 'umap', 'GPUtil', 'scipy'],
#    long_description=open('README.md').read(),
#    url="https://github.com/hmmartiny/cycoda",
#    extras_require={"GPU":  ['cupy']},

# )
